@@ -21,6 +21,7 @@
 
 #include "write-any-file.h"
 #include "priv-set.h"
+#include "root-uid.h"
 
 #include <unistd.h>
 
@@ -40,7 +41,7 @@ can_write_any_file (void)
       can = (priv_set_ismember (PRIV_FILE_DAC_WRITE) == 1);
 #else
       /* In traditional Unix, only root can unlink directories.  */
-      can = (geteuid () == 0);
+      can = (geteuid () == ROOT_UID);
 #endif
       can_write = can;
       initialized = true;
