@@ -1,5 +1,5 @@
 /* basename -- strip directory and suffix from file names
-   Copyright (C) 1990-1997, 1999-2012 Free Software Foundation, Inc.
+   Copyright (C) 1990-2012 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,65 +14,71 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-/* Usage: basename name [suffix]
-   NAME is a file name; SUFFIX is a suffix to strip from it.
-
-   basename /usr/foo/lossage/functions.l
-   => functions.l
-   basename /usr/foo/lossage/functions.l .l
-   => functions
-   basename functions.lisp p
-   => functions.lis */
-
 #include <config.h>
 #include <getopt.h>
 #include <stdio.h>
 #include <sys/types.h>
 
 #include "system.h"
-#include "long-options.h"
 #include "error.h"
 #include "quote.h"
 
-/* The official name of this program (e.g., no `g' prefix).  */
+/* The official name of this program (e.g., no 'g' prefix).  */
 #define PROGRAM_NAME "basename"
 
 #define AUTHORS proper_name ("David MacKenzie")
 
+static struct option const longopts[] =
+{
+  {"multiple", no_argument, NULL, 'a'},
+  {"suffix", required_argument, NULL, 's'},
+  {"zero", no_argument, NULL, 'z'},
+  {GETOPT_HELP_OPTION_DECL},
+  {GETOPT_VERSION_OPTION_DECL},
+  {NULL, 0, NULL, 0}
+};
+
 void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
-    fprintf (stderr, _("Try `%s --help' for more information.\n"),
-             program_name);
+    emit_try_help ();
   else
     {
       printf (_("\
 Usage: %s NAME [SUFFIX]\n\
-  or:  %s OPTION\n\
+  or:  %s OPTION... NAME...\n\
 "),
               program_name, program_name);
       fputs (_("\
 Print NAME with any leading directory components removed.\n\
 If specified, also remove a trailing SUFFIX.\n\
 \n\
+"), stdout);
+
+      fputs (_("\
+  -a, --multiple       support multiple arguments and treat each as a NAME\n\
+  -s, --suffix=SUFFIX  remove a trailing SUFFIX\n\
+  -z, --zero           separate output with NUL rather than newline\n\
 "), stdout);
       fputs (HELP_OPTION_DESCRIPTION, stdout);
       fputs (VERSION_OPTION_DESCRIPTION, stdout);
       printf (_("\
 \n\
 Examples:\n\
-  %s /usr/bin/sort       Output \"sort\".\n\
-  %s include/stdio.h .h  Output \"stdio\".\n\
+  %s /usr/bin/sort          -> \"sort\"\n\
+  %s include/stdio.h .h     -> \"stdio\"\n\
+  %s -s .h include/stdio.h  -> \"stdio\"\n\
+  %s -a any/str1 any/str2   -> \"str1\" followed by \"str2\"\n\
 "),
-              program_name, program_name);
+              program_name, program_name, program_name, program_name);
       emit_ancillary_info ();
     }
   exit (status);
 }
 
 /* Remove SUFFIX from the end of NAME if it is there, unless NAME
-   consists entirely of SUFFIX. */
+   consists entirely of SUFFIX.  */
 
 static void
 remove_suffix (char *name, const char *suffix)
@@ -90,10 +96,35 @@ remove_suffix (char *name, const char *suffix)
     *np = '\0';
 }
 
+/* Perform the basename operation on STRING.  If SUFFIX is non-NULL, remove
+   the trailing SUFFIX.  Finally, output the result string.  */
+
+static void
+perform_basename (const char *string, const char *suffix, bool use_nuls)
+{
+  char *name = base_name (string);
+  strip_trailing_slashes (name);
+
+  /* Per POSIX, 'basename // /' must return '//' on platforms with
+     distinct //.  On platforms with drive letters, this generalizes
+     to making 'basename c: :' return 'c:'.  This rule is captured by
+     skipping suffix stripping if base_name returned an absolute path
+     or a drive letter (only possible if name is a file-system
+     root).  */
+  if (suffix && IS_RELATIVE_FILE_NAME (name) && ! FILE_SYSTEM_PREFIX_LEN (name))
+    remove_suffix (name, suffix);
+
+  fputs (name, stdout);
+  putchar (use_nuls ? '\0' : '\n');
+  free (name);
+}
+
 int
 main (int argc, char **argv)
 {
-  char *name;
+  bool multiple_names = false;
+  bool use_nuls = false;
+  const char *suffix = NULL;
 
   initialize_main (&argc, &argv);
   set_program_name (argv[0]);
@@ -103,10 +134,33 @@ main (int argc, char **argv)
 
   atexit (close_stdout);
 
-  parse_long_options (argc, argv, PROGRAM_NAME, PACKAGE_NAME, Version,
-                      usage, AUTHORS, (char const *) NULL);
-  if (getopt_long (argc, argv, "+", NULL, NULL) != -1)
-    usage (EXIT_FAILURE);
+  while (true)
+    {
+      int c = getopt_long (argc, argv, "+as:z", longopts, NULL);
+
+      if (c == -1)
+        break;
+
+      switch (c)
+        {
+        case 's':
+          suffix = optarg;
+
+        case 'a':
+          multiple_names = true;
+          break;
+
+        case 'z':
+          use_nuls = true;
+          break;
+
+        case_GETOPT_HELP_CHAR;
+        case_GETOPT_VERSION_CHAR (PROGRAM_NAME, AUTHORS);
+
+        default:
+          usage (EXIT_FAILURE);
+        }
+    }
 
   if (argc < optind + 1)
     {
@@ -114,27 +168,20 @@ main (int argc, char **argv)
       usage (EXIT_FAILURE);
     }
 
-  if (optind + 2 < argc)
+  if (!multiple_names && optind + 2 < argc)
     {
       error (0, 0, _("extra operand %s"), quote (argv[optind + 2]));
       usage (EXIT_FAILURE);
     }
 
-  name = base_name (argv[optind]);
-  strip_trailing_slashes (name);
-
-  /* Per POSIX, `basename // /' must return `//' on platforms with
-     distinct //.  On platforms with drive letters, this generalizes
-     to making `basename c: :' return `c:'.  This rule is captured by
-     skipping suffix stripping if base_name returned an absolute path
-     or a drive letter (only possible if name is a file-system
-     root).  */
-  if (argc == optind + 2 && IS_RELATIVE_FILE_NAME (name)
-      && ! FILE_SYSTEM_PREFIX_LEN (name))
-    remove_suffix (name, argv[optind + 1]);
-
-  puts (name);
-  free (name);
+  if (multiple_names)
+    {
+      for (; optind < argc; optind++)
+        perform_basename (argv[optind], suffix, use_nuls);
+    }
+  else
+    perform_basename (argv[optind],
+                      optind + 2 == argc ? argv[optind + 1] : NULL, use_nuls);
 
   exit (EXIT_SUCCESS);
 }
