@@ -540,7 +540,7 @@ Copy a file, converting and formatting according to the operands.\n\
 "), stdout);
       fputs (_("\
 \n\
-BLOCKS and BYTES may be followed by the following multiplicative suffixes:\n\
+N, BLOCKS and BYTES may be followed by the following multiplicative suffixes:\n\
 c =1, w =2, b =512, kB =1000, K =1024, MB =1000*1000, M =1024*1024, xM =M\n\
 GB =1000*1000*1000, G =1024*1024*1024, and so on for T, P, E, Z, Y.\n\
 \n\
@@ -2211,7 +2211,7 @@ main (int argc, char **argv)
     }
   else
     {
-      mode_t perms = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH;
+      mode_t perms = MODE_RW_UGO;
       int opts
         = (output_flags
            | (conversions_mask & C_NOCREAT ? 0 : O_CREAT)
